/*
 ******************************************************************************
 *
 * Copyright Ben Suffolk, 2004/5
 *
 * Ben@vanilla.net
 *
 * You may not reverse engineer, decompile or disassemble the software, except
 * and only to the extent that such activity is expressly permitted by
 * applicable law notwithstanding this limitation.
 *
 * You may not sell, rent, lease, sub-lease or incorporate the whole or any
 * part of the use of the software in any other program or system without the
 * express written agreement
 *
 ******************************************************************************
 *
 * Receive notifications from teh HWInterface and display them in the console
 * window
 *
 ******************************************************************************
 *
 * History :-
 *
 * Last Author:   $Author: suffo_b $
 * Last modified: $Date: 2005/03/21 09:06:22 $
 * Revision:      $Revision: 1.1 $
 *
 * Author          Date         Description
 *
 * Ben Suffolk     21/03/2005   Added comments, and tidied up
 *
 ******************************************************************************
*/

#import "ConsoleController.h"
#import <HWInterface.h>

@implementation ConsoleController

/**
 *
 * This method is called once the object has been loaded from the NIB file
 *
 **/
- (void)awakeFromNib
 {
 NSSize space;

 space.width = 5;
 space.height = 5;
 
 [console setTextContainerInset:space];

 // Register for updates
 [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(receiveDebugNotification:) name:@"DMXDebug" object:nil];
 [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(receiveErrorNotification:) name:@"DMXError" object:nil];
 [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(receiveVersionNotification:) name:@"DMXVersion" object:nil];
 [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(receiveResponseNotification:) name:@"DMXResponse" object:nil];
 [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(receiveValueNotification:) name:@"DMXValue" object:nil];

 [self addLine:@"Start of console application" type:"DEBUG"];
 
 [[NSNotificationCenter defaultCenter] postNotificationName:@"DMXDebug" object:@"Test Notification"];

 }
 
 
/**
 *
 * Clear the console
 *
 **/
- (IBAction)Clear:(id)sender
 {
 [console setString:@""];
 }


/**
 *
 * Receive the notification
 *
 **/
- (void) receiveDebugNotification:(NSNotification *)aNotification
 {
 [self addLine:(NSString *)[aNotification object] type:"DEBUG"];
 }


/**
 *
 * Receive the notification
 *
 **/
- (void) receiveErrorNotification:(NSNotification *)aNotification
 {
 [self addLine:(NSString *)[aNotification object] type:"ERROR"];
 }


/**
 *
 * Receive the notification
 *
 **/
- (void) receiveResponseNotification:(NSNotification *)aNotification
 {
 DMXResponse *resp = (DMXResponse *)[aNotification object];

 [self addLine:[NSString stringWithFormat:@"%02X:%s %u %u",[resp getCode],[HWInterface lookupResponse:[resp getCode]],[resp getChannel],[resp getValue]] type:"RESPONSE"];
 }


/**
 *
 * Receive the notification
 *
 **/
- (void) receiveValueNotification:(NSNotification *)aNotification
 {
 DMXResponse *resp = (DMXResponse *)[aNotification object];

 [self addLine:[NSString stringWithFormat:@"Channel %u Value %u",[resp getChannel],[resp getValue]] type:"VALUE"];
 }

/**
 *
 * Receive the notification
 *
 **/
- (void) receiveVersionNotification:(NSNotification *)aNotification
 {
 DMXVersion *version = (DMXVersion *)[aNotification object];

 [self addLine:[NSString stringWithFormat:@"%d.%d \"%@\"",[version getMajor],[version getMinor],[version getString]] type:"VERSION"];
 }


/**
 *
 * Add a line of text to the console
 *
 **/
- (void)addLine:(NSString *)text type:(char *)cString
 {
 NSRange range;
 
 [console setString:[[console string] stringByAppendingFormat:@"%s: %@\n",cString,text]];
 
 range.location=[[console string] length] - 2;
 range.length = 1;
 
 [console scrollRangeToVisible:range];
 
 }


/**
 *
 * Called when the object gets deallocated
 *
 **/
- (void)dealloc
 {
 // Don't need notifications anymore
 [[NSNotificationCenter defaultCenter] removeObserver:self];
 }


@end
